@@ -6,6 +6,8 @@ config.addonManager.repositoryBranch =
 "Specifies the git branch used by the addon manager."
 config.addonManager.repositoryPath =
 "Specifies the git path used by the addon manager."
+config.addonRepositoryPath        =
+"Specifies the addon repository path (not related to the addon manager)."
 config.runtime.version            =
 "Lua runtime version."
 config.runtime.path               =
@@ -113,8 +115,8 @@ config.diagnostics.ignoredFiles.Opened   =
 "Only when these files are opened will it be diagnosed."
 config.diagnostics.ignoredFiles.Disable  =
 "These files are not diagnosed."
-config.diagnostics.disableScheme  =
-'Do not diagnose Lua files that use the following scheme.'
+config.diagnostics.validScheme  =
+'Enable diagnostics for Lua files that use the following scheme.'
 config.diagnostics.unusedLocalExclude =
 'Do not diagnose `unused-local` when the variable name matches the following pattern.'
 config.workspace.ignoreDir        =
@@ -279,7 +281,10 @@ Read [formatter docs](https://github.com/CppCXY/EmmyLuaCodeStyle/tree/master/doc
 config.spell.dict                        =
 'Custom words for spell checking.'
 config.nameStyle.config                  =
-'Set name style config'
+[[
+Set name style config.
+Read [formatter docs](https://github.com/CppCXY/EmmyLuaCodeStyle/tree/master/docs) to learn usage.
+]]
 config.telemetry.enable                  =
 [[
 Enable telemetry to send your editor information and error logs over the network. Read our privacy policy [here](https://luals.github.io/privacy/#language-server).
@@ -289,7 +294,7 @@ config.misc.parameters                   =
 config.misc.executablePath               =
 'Specify the executable path in VSCode.'
 config.language.fixIndent                =
-'(VSCode only) Fix incorrect auto-indentation, such as incorrect indentation when line breaks occur within a string containing the word "function."'
+'(VSCode only) Fix incorrect auto-indentation, such as incorrect indentation when line breaks occur within a string containing the word "function".'
 config.language.completeAnnotation       =
 '(VSCode only) Automatically insert "---@ " after a line break following a annotation.'
 config.type.castNumberToInteger          =
@@ -316,12 +321,22 @@ config.type.checkTableShape              =
 [[
 Strictly check the shape of the table.
 ]]
+config.type.inferTableSize               =
+'Maximum number of table fields analyzed during type inference.'
 config.doc.privateName                   =
 'Treat specific field names as private, e.g. `m_*` means `XXX.m_id` and `XXX.m_type` are private, witch can only be accessed in the class where the definition is located.'
 config.doc.protectedName                 =
 'Treat specific field names as protected, e.g. `m_*` means `XXX.m_id` and `XXX.m_type` are protected, witch can only be accessed in the class where the definition is located and its subclasses.'
 config.doc.packageName                   =
 'Treat specific field names as package, e.g. `m_*` means `XXX.m_id` and `XXX.m_type` are package, witch can only be accessed in the file where the definition is located.'
+config.doc.regengine                     =
+'The regular expression engine used for matching documentation scope names.'
+config.doc.regengine.glob                =
+'The default lightweight pattern syntax.'
+config.doc.regengine.lua                 =
+'Full Lua-style regular expressions.'
+config.docScriptPath                     =
+'The regular expression engine used for matching documentation scope names.'
 config.diagnostics['unused-local']          =
 'Enable unused local variable diagnostics.'
 config.diagnostics['unused-function']       =
@@ -339,7 +354,7 @@ config.diagnostics['trailing-space']        =
 config.diagnostics['redefined-local']       =
 'Enable redefined local variable diagnostics.'
 config.diagnostics['newline-call']          =
-'Enable newline call diagnostics. Is\'s raised when a line starting with `(` is encountered, which is syntactically parsed as a function call on the previous line.'
+'Enable newline call diagnostics. It\'s raised when a line starting with `(` is encountered, which is syntactically parsed as a function call on the previous line.'
 config.diagnostics['newfield-call']         =
 'Enable newfield call diagnostics. It is raised when the parenthesis of a function call appear on the following line when defining a field in a table.'
 config.diagnostics['redundant-parameter']   =
@@ -406,6 +421,8 @@ config.diagnostics['missing-return-value']  =
 'Enable diagnostics for return statements without values although the containing function declares returns.'
 config.diagnostics['need-check-nil']        =
 'Enable diagnostics for variable usages if `nil` or an optional (potentially `nil`) value was assigned to the variable before.'
+config.diagnostics['unnecessary-assert']    =
+'Enable diagnostics for redundant assertions on truthy values.'
 config.diagnostics['no-unknown']            =
 'Enable diagnostics for cases in which the type cannot be inferred.'
 config.diagnostics['not-yieldable']         =
@@ -458,6 +475,6 @@ command.addon_manager.open =
 command.reloadFFIMeta =
 'Lua: Reload luajit ffi meta'
 command.startServer =
-'Lua: (debug) Start Language Server'
+'Lua: Restart Language Server'
 command.stopServer =
-'Lua: (debug) Stop Language Server'
+'Lua: Stop Language Server'
